@@ -12,7 +12,8 @@ def create_project(root_path, output_path_root):
             continue
         if path.is_dir():
             output_path_dir = output_path_root/ path.relative_to(root_path)
-            output_path_dir.mkdir()
+            if not output_path_dir.is_dir():
+                output_path_dir.mkdir()
             continue
         text = path.read_text()
         # print(text)
@@ -32,7 +33,8 @@ def create_package(root_path, output_path_root, package_name, package_type):
             path_parts = [Template(p).substitute(package_name=package_name) for p in path.relative_to(root_path).parts]
             output_path_dir = output_path_root/ Path(*path_parts)
             print(output_path_dir)
-            output_path_dir.mkdir()
+            if not output_path_dir.is_dir():
+                output_path_dir.mkdir()
             continue
         print(path.relative_to(root_path))
         text = path.read_text()
@@ -61,7 +63,8 @@ def main():
     output_path_root = Path(args.project_path).resolve()
     package_name = args.package_name
 
-    output_path_root.mkdir()
+    if not output_path_root.is_dir():
+        output_path_root.mkdir()
 
     if args.project_or_app == "startproject":
         create_project(root_path, output_path_root)
